Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/supermerill/SuperSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorfoxox <foxox.jd@live.com>2019-12-03 06:48:01 +0300
committerVojtěch Bubník <5830947+bubnikv@users.noreply.github.com>2020-01-20 19:16:49 +0300
commit07d6fd8f7ec84d1077752f676827aa774224d1f8 (patch)
tree0b6560b50ebe81df189205c894db813fa200c133 /src/slic3r/GUI/PresetBundle.hpp
parent9f65b6bc96f1584d8034d10e66dd109662a310b9 (diff)
Platter->Plater
Diffstat (limited to 'src/slic3r/GUI/PresetBundle.hpp')
-rw-r--r--src/slic3r/GUI/PresetBundle.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/slic3r/GUI/PresetBundle.hpp b/src/slic3r/GUI/PresetBundle.hpp
index 5205042c5..ff27d0023 100644
--- a/src/slic3r/GUI/PresetBundle.hpp
+++ b/src/slic3r/GUI/PresetBundle.hpp
@@ -109,8 +109,8 @@ public:
// Export a config bundle file containing all the presets and the names of the active presets.
void export_configbundle(const std::string &path, bool export_system_settings = false);
- // Update a filament selection combo box on the platter for an idx_extruder.
- void update_platter_filament_ui(unsigned int idx_extruder, GUI::PresetComboBox *ui);
+ // Update a filament selection combo box on the plater for an idx_extruder.
+ void update_plater_filament_ui(unsigned int idx_extruder, GUI::PresetComboBox *ui);
// Enable / disable the "- default -" preset.
void set_default_suppressed(bool default_suppressed);